==> haskell-email-validate-2.3.2.8-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.8
id: email-validate-2.3.2.8-3pKmuAThfE6bNsTe7gk2a
key: email-validate-2.3.2.8-3pKmuAThfE6bNsTe7gk2a
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 482896a82612595e92a1811dc8e59053
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.1/site-local/email-validate-2.3.2.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/email-validate-2.3.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/email-validate-2.3.2.8
hs-libraries: HSemail-validate-2.3.2.8-3pKmuAThfE6bNsTe7gk2a
depends:
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.9-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.9
id: email-validate-2.3.2.9-E2IvBKPgpCL32bg54cm1tM
key: email-validate-2.3.2.9-E2IvBKPgpCL32bg54cm1tM
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: b9f012b2e954d1b438c67a5812e6456c
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.2/site-local/email-validate-2.3.2.9
library-dirs: /usr/lib/ghc-8.6.2/site-local/email-validate-2.3.2.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/email-validate-2.3.2.9
hs-libraries: HSemail-validate-2.3.2.9-E2IvBKPgpCL32bg54cm1tM
depends:
    attoparsec-0.13.2.2-CmkmuzHxC7WKLrfPgrn9Wq base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
